# -*- coding: utf-8 -*-

from django.contrib import admin
from django.utils.translation import ugettext_lazy as _

from jmb.core.admin.options import ExtendibleModelAdmin
from acomea.premium.models import PremiumUrl, EmailMessage


class PremiumUrlAdmin(ExtendibleModelAdmin):
    advanced_search_fields = (
        ('contact',),
        ('contact__first_name__icontains:Nome', 'contact__last_name__icontains:Cognome'),
        ('premium_url__icontains:Premium url',),
    )

    list_display = (
        'contact', 'date_create', 'premium_url', 'get_edit_icon', 'get_delete_icon',
    )
    fieldsets = (
        (_('logs admin'), {
            'fields': (
                'creator', 'last_modifier', 'date_last_modify',
            ),
            'classes': ('collapse',)
        }),
        (None, {
            'fields': ('date_create', 'contact', 'premium_url',),
        }),
    )
    readonly_fields = ('date_create', 'contact', 'premium_url')
    search_fields = ('contact__first_name', 'contact__last_name', 'premium_url',)

    def queryset(self, request):
        qs = super(PremiumUrlAdmin, self).queryset(request)
        return qs.filter(is_first=True)


class EmailMessageAdmin(ExtendibleModelAdmin):
    list_display = ('name', 'subject', 'get_edit_icon')
    fieldsets = (
        (_('logs admin'), {
            'fields': (
                'creator', 'date_create',
                'last_modifier', 'date_last_modify',
            ),
            'classes': ('collapse',)
        }),
        (None, {'fields': ('name', 'subject', 'body',)}),
    )

admin.site.register(PremiumUrl, PremiumUrlAdmin)
admin.site.register(EmailMessage, EmailMessageAdmin)
