# -*- coding: utf-8 -*-

from django.db import models
from django.conf import settings
from django.utils.translation import ugettext as _
from cms.models.pluginmodel import CMSPlugin

from jmb.core.db.cmsmodels import StatusModel
from jmb.core.db.fields import HTMLFieldTinyMCE
from acomea.contact.models import Group
from acomea.premium.models import EmailMessage


class PremiumBlockSettings(CMSPlugin, StatusModel):
    redirect_to = models.SlugField(
        _("Redirect to"),
        max_length=100,
        help_text=_("page slug for registration redirect")
    )
    group = models.ForeignKey(
        Group,
        blank=True, null=True,
        related_name='premium_block_plugin_settings',
        verbose_name=_('Group'),
        help_text=_('Group where contact will be assigned when premium content is displayed'),
    )

    class Meta:
        app_label = "premium"


class PremiumRegistrationSettings(CMSPlugin, StatusModel):
    slug = models.SlugField(
        max_length=100,
        null=True, blank=True
    )
    registration_body = HTMLFieldTinyMCE(
        verbose_name=_('registration body'),
        null=True, blank=True,
    )
    registration_disclaimer = HTMLFieldTinyMCE(
        verbose_name=_('registration disclaimer'),
        null=True, blank=True,
    )
    registration_done = HTMLFieldTinyMCE(
        verbose_name=_('registration done'),
        null=True, blank=True,
    )
    disclaimer_title = models.CharField(
        verbose_name=_("Disclaimer title"),
        max_length=100,
        blank=True, null=True,
    )
    disclaimer_body = HTMLFieldTinyMCE(
        verbose_name=_('disclaimer body'),
        null=True, blank=True,
    )
    sent_from = models.EmailField(
        _('Indirizzo mittente delle mail'),
        default="sender@example.org",
    )
    activation_done_template = models.CharField(
        max_length=100,
        choices=settings.PREMIUM_CMSPLUGIN_PREMIUMREGISTRATION_ACTIVATION_DONE_TEMPLATES,
        default="bootstrap3/premium/cms_plugins/activation_done.html"
    )
    post_registration_email = models.ForeignKey(
        EmailMessage,
        related_name='premium_registration_settings',
        verbose_name=_('post registration email'),
        help_text=_("{{confirm_link}} as registration confirm. {{user}} for first_name, last_name, email"),
        blank=True, null=True,
    )
    email_activation_done_template = models.CharField(
        max_length=100,
        choices=settings.PREMIUM_CMSPLUGIN_PREMIUMREGISTRATION_EMAIL_ACTIVATIONDONE_TEMPLATES,
        default="bootstrap3/premium/cms_plugins/activation_done_email.html"
    )
    missing_session_redirect_to = models.SlugField(
        _("Redirect to"),
        max_length=100,
        help_text=_("Page slug to use for redirecting when session is missing")
    )
    has_social = models.BooleanField(
        default=False,
        verbose_name=_('has social')
    )
    contact_group = models.ForeignKey(
        Group,
        related_name='premium_registration_plugin_settings',
        verbose_name=_('contact group'),
        null=True, blank=True,
    )

    def __unicode__(self):
        return "%s %s" % (
            ('On - ' if self.status else 'Off - '),
            self.slug if self.slug else self.id
        )

    class Meta:
        app_label = "premium"


class PremiumSetUserInGroupSettings(CMSPlugin, StatusModel):
    name = models.CharField(
        _("Name"),
        max_length=100,
    )
    group = models.ForeignKey(
        'contact.Group',
        related_name="premium_set_user_settings"
    )

    class Meta:
        app_label = "premium"

    def __unicode__(self):
        return u"{}".format(self.name)
