#! -*- coding: utf-8 -*-

from django.conf import settings
from django.db import models
from django.utils.translation import ugettext_lazy as _

from jmb.core.db.models import DateModel, UserModel
from jmb.core.db.fields import HTMLFieldTinyMCE
from acomea.contact.models import Contact


class PremiumUrl(DateModel, UserModel):
    contact = models.ForeignKey(
        Contact,
        related_name="premium_urls",
        verbose_name=_("Contact")
    )
    premium_url = models.URLField(
        max_length=250,
        verbose_name=_("Premium redirect url"),
    )
    is_first = models.BooleanField(
        default=False,
        verbose_name=_('is first'),
    )

    class Meta:
        verbose_name = _("Premium url")
        verbose_name_plural = _("Premium urls")
        ordering = ('contact', '-date_create',)

    def save(self, *args, **kwargs):
        if not self.id and not PremiumUrl.objects.filter(contact=self.contact).count():
            self.is_first = True
        super(PremiumUrl, self).save(*args, **kwargs)


class EmailMessage(DateModel, UserModel):
    name = models.CharField(
        max_length=255,
        verbose_name=_('name'),
    )
    subject = models.CharField(
        max_length=255,
        verbose_name=_('subject'),
    )
    body = HTMLFieldTinyMCE(
        verbose_name=_('email message'),
    )

    class Meta:
        verbose_name = _('email message')
        verbose_name_plural = _('email messages')

    def __unicode__(self):
        return u"{0}".format(self.name)


if settings.CMS_ENABLED:
    import acomea.premium.cms.models
    #import acomea.premium.cms.app